summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--chrome/browser/shell_dialogs.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/shell_dialogs.h b/chrome/browser/shell_dialogs.h
index 46218b9..3765864 100644
--- a/chrome/browser/shell_dialogs.h
+++ b/chrome/browser/shell_dialogs.h
@@ -124,7 +124,7 @@ class SelectFileDialog
// Shows a dialog box for selecting a font.
class SelectFontDialog
- : public base::RefCountedThreadSafe<SelectFileDialog>,
+ : public base::RefCountedThreadSafe<SelectFontDialog>,
public BaseShellDialog {
public:
@@ -135,12 +135,12 @@ class SelectFontDialog
public:
// Notifies the Listener that a font selection has been made. The font
// details are supplied in |font|. |params| is contextual passed to
- // SelectFile.
+ // SelectFont.
virtual void FontSelected(const gfx::Font& font, void* params) = 0;
// Notifies the Listener that the font selection was aborted (via the user
// canceling or closing the selection dialog box, for example). |params| is
// contextual passed to SelectFile.
virtual void FontSelectionCanceled(void* params) {};
};
@@ -171,7 +171,7 @@ class SelectFontDialog
int font_size) = 0;
protected:
- friend class base::RefCountedThreadSafe<SelectFileDialog>;
+ friend class base::RefCountedThreadSafe<SelectFontDialog>;
virtual ~SelectFontDialog() {}
};
@@ -135,12 +135,12 @@ class SelectFontDialog
// Notifies the Listener that the font selection was aborted (via the user
// canceling or closing the selection dialog box, for example). |params| is
- // contextual passed to SelectFile.
+ // contextual passed to SelectFont.
virtual void FontSelectionCanceled(void* params) {};
};